<?php

namespace Drupal\eca_crowdsec\EventSubscriber;

use Drupal\crowdsec\Event\IpBaseEvent;
use Drupal\crowdsec\Event\IpSignalled;
use Drupal\crowdsec\Event\ScenarioList;
use Drupal\eca_crowdsec\Plugin\ECA\Event\CrowdSecEvent;
use Drupal\eca\EcaEvents;
use Drupal\eca\Event\BeforeInitialExecutionEvent;
use Drupal\eca\EventSubscriber\EcaBase;

/**
 * CrowdSec ECA event subscriber.
 */
class CrowdSec extends EcaBase {

  /**
   * Subscriber method before initial execution.
   *
   * Adds event data to the Token service.
   *
   * @param \Drupal\eca\Event\BeforeInitialExecutionEvent $before_event
   *   The according event.
   */
  public function onBeforeInitialExecution(BeforeInitialExecutionEvent $before_event): void {
    $event = $before_event->getEvent();
    if ($event instanceof ScenarioList) {
      $this->tokenService->addTokenData('crowdsec:scenario:list', $event->getScenarios());
    }
    elseif ($event instanceof IpBaseEvent) {
      $this->tokenService->addTokenData('crowdsec:ip', $event->getIp());
      if ($event instanceof IpSignalled) {
        $this->tokenService->addTokenData('crowdsec:scenario', $event->getScenario());
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    $events = [];
    foreach (CrowdSecEvent::definitions() as $definition) {
      $events[$definition['event_name']][] = ['onEvent'];
    }
    $events[EcaEvents::BEFORE_INITIAL_EXECUTION][] = [
      'onBeforeInitialExecution',
      -100,
    ];
    return $events;
  }

}
